@@ -1,13 +1,11 @@
 package Data::Riak;
 {
-  $Data::Riak::VERSION = '1.7';
+  $Data::Riak::VERSION = '1.8';
 }
 # ABSTRACT: An interface to a Riak server.
 
 use Moose;
 
-use Class::Load 'load_class';
-
 use Data::Riak::Result;
 use Data::Riak::Result::Object;
 use Data::Riak::ResultSet;
@@ -18,27 +16,8 @@ use Data::Riak::HTTP;
 
 use namespace::autoclean;
 
+with 'Data::Riak::Role::Frontend';
 
-has transport => (
-    is       => 'ro',
-    does     => 'Data::Riak::Transport',
-    required => 1,
-    handles  => {
-        'base_uri' => 'base_uri'
-    }
-);
-
-has request_classes => (
-    traits  => ['Hash'],
-    is      => 'ro',
-    isa     => 'HashRef[Str]',
-    builder => '_build_request_classes',
-    handles => {
-        _available_request_classes => 'values',
-        request_class_for          => 'get',
-        has_request_class_for      => 'exists',
-    },
-);
 
 sub _build_request_classes {
     return +{
@@ -50,24 +29,7 @@ sub _build_request_classes {
     }
 }
 
-sub BUILD {
-    my ($self) = @_;
-
-    load_class $_
-        for $self->_available_request_classes;
-}
-
-sub _create_request {
-    my ($self, $args) = @_;
-
-    my %args_copy = %{ $args };
-    my $type = delete $args_copy{type};
-
-    confess sprintf 'Unknown request class %s', $type
-        unless $self->has_request_class_for($type);
-
-    return $self->request_class_for($type)->new(\%args_copy);
-}
+sub _build_bucket_class { 'Data::Riak::Bucket' }
 
 sub send_request {
     my ($self, $request_data) = @_;
@@ -79,57 +41,10 @@ sub send_request {
     return unless @results;
 
     if (@results == 1 && $results[0]->does('Data::Riak::Result::Single')) {
-        return $results[0];
+        return $request->_mangle_retval($results[0]);
     }
 
-    return Data::Riak::ResultSet->new({ results => \@results });
-}
-
-
-sub ping {
-    my ($self) = @_;
-    return $self->send_request({ type => 'Ping' })->status_code == 200 ? 1 : 0;
-}
-
-
-sub status {
-    my ($self) = @_;
-    return $self->send_request({ type => 'Status' })->json_value;
-}
-
-
-sub _buckets {
-    my $self = shift;
-    return $self->send_request({
-        type => 'ListBuckets',
-    })->json_value->{buckets};
-}
-
-
-sub bucket {
-    my ($self, $bucket_name) = @_;
-    return Data::Riak::Bucket->new({
-        riak => $self,
-        name => $bucket_name
-    })
-}
-
-sub resolve_link {
-    my ($self, $link) = @_;
-    $self->bucket( $link->bucket )->get( $link->key );
-}
-
-sub linkwalk {
-    my ($self, $args) = @_;
-    my $object = $args->{object} || confess 'You must have an object to linkwalk';
-    my $bucket = $args->{bucket} || confess 'You must have a bucket for the original object to linkwalk';
-
-    return $self->send_request({
-        type => 'LinkWalk',
-        bucket_name => $bucket,
-        key => $object,
-        params => $args->{params},
-    });
+    return $request->_mangle_retval(Data::Riak::ResultSet->new({ results => \@results }));
 }
 
 
@@ -148,7 +63,7 @@ Data::Riak - An interface to a Riak server.
 
 =head1 VERSION
 
-version 1.7
+version 1.8
 
 =head1 SYNOPSIS
 
