@@ -1,6 +1,6 @@
 package Data::Riak::Request::GetBucketProps;
 {
-  $Data::Riak::Request::GetBucketProps::VERSION = '1.7';
+  $Data::Riak::Request::GetBucketProps::VERSION = '1.8';
 }
 
 use Moose;
@@ -17,6 +17,11 @@ sub as_http_request_args {
     };
 }
 
+sub _mangle_retval {
+    my ($self, $ret) = @_;
+    $ret->json_value->{props};
+}
+
 with 'Data::Riak::Request::WithBucket';
 
 has '+result_class' => (
@@ -37,7 +42,7 @@ Data::Riak::Request::GetBucketProps
 
 =head1 VERSION
 
-version 1.7
+version 1.8
 
 =head1 AUTHORS
 
